@@ -137,7 +137,7 @@ public class TurnOnSSL implements IPluginConfigPanel, EncryptionOptions, IClient
 	    if (cipherFamily.toLowerCase().equals("fortezza")) {
 		cipherPref = new CipherPreferenceDialog(null,
 							"",
-						        (String)(securitySettings.get("ssl3")),
+							(String)(securitySettings.get("ssl3")),
 							"") {
 		    public void cipherStateChanged(String SSLVersion, String cipher, boolean enabled) {
 			setDirty(true);
@@ -175,7 +175,7 @@ public class TurnOnSSL implements IPluginConfigPanel, EncryptionOptions, IClient
 	    Object tlsSetting  = securitySettings.get("tls");
 
 	    //construct a default cipher preference dialog, and get the default settings
-	    CipherPreferenceDialog cipherPref = new CipherPreferenceDialog(null, true, true, true, domestic, false);
+	    CipherPreferenceDialog cipherPref = new CipherPreferenceDialog(null, true, true, true, domestic, false, true);
 
 	    if ((ssl2Setting == null) || 
 		(ssl2Setting.toString().length() == 0) ||
